# Generated by Django 3.2 on 2021-04-17 15:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drf_file_upload', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='authenticateduploadedfile',
            name='uuid',
            field=models.CharField(default=None, max_length=64, null=True, unique=True),
        ),
    ]
